yakumo.nova.v2.aggregate

Package yakumo :: Package nova :: Package v2 :: Module aggregate |
[hide private]
[frames] | no frames]

# Module aggregate

source code

Resource class and its manager for aggregates in Compute API v2

Classes | [hide private]
| Resource Resource class for aggregates in Compute API v2
| Manager Manager class for aggregates in Compute API v2

Variables | [hide private]
| ATTRIBUTE_MAPPING = ``[``(``'``id``'``,` `'``id``'``,` <yakumo.mapper.NoopClass obj`...``
| __package__ = ``'``yakumo.nova.v2``'``

Variables Details | [hide private]

  ### ATTRIBUTE_MAPPING Value:
      [('id', 'id', mapper.Noop), ('name', 'name', mapper.Noop), ('hosts', '
      hosts', mapper.Noop), ('availability_zone', 'availability_zone', mappe
      r.Noop), ('metadata', 'metadata', mapper.Noop), ('created_at', 'create
      d_at', mapper.DateTime), ('updated_at', 'updated_at', mapper.DateTime)
      , ('deleted_at', 'deleted_at', mapper.DateTime), ('is_deleted', 'delet
      ed', mapper.Noop),]